"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const index_js_1 = require("../index.js");
const dotenv_1 = __importDefault(require("dotenv"));
async function main() {
    dotenv_1.default.config();
    const API_KEY = process.env['COINSPOT_API_KEY'];
    const API_SECRET = process.env['COINSPOT_API_SECRET'];
    if (!API_KEY || !API_SECRET) {
        console.error('API key or secret not found in environment variables');
        return;
    }
    const coinspot = new index_js_1.Coinspot(API_KEY, API_SECRET);
    try {
        const prices = await coinspot.latestPrices();
        console.log('Latest prices:', prices);
        const bitcoins = await coinspot.latestCoinPrice('btc');
        console.log('Bitcoin price:', bitcoins);
        const ethers = await coinspot.latestCoinPrice('eth');
        console.log('Ethereum price:', ethers);
        const coins = ['btc', 'eth', 'bch', 'ltc', 'doge'];
        for (const coin of coins) {
            const addr = await coinspot.coinDepositAddress(coin);
            for (const network of addr.networks) {
                console.log(`${coin.toUpperCase()}: ${network.address}`);
            }
        }
    }
    catch (error) {
        console.error('An error occurred:', error);
    }
}
main().catch(console.error);
//# sourceMappingURL=demo.js.map